==> dart_blocks-0.0.15.tar.gz: lib/softcorp_authorize/softcorp_authorize.dart <==
import 'package:dart_softcorp_cloud/cloud_project.pbgrpc.dart';
import 'package:jwt_decoder/jwt_decoder.dart';

abstract class Authorize {
  Future<String> getAccessToken();
}

class SoftcorpAuthorize implements Authorize {
  // _grpcProjectClient is an object to communicate with the server
  late final ProjectServiceClient _grpcProjectClient;

  // _apiKey used to authorize requests
  String _apiKey = "";

  // _accessToken is used to connect clients to the api
  String _accessToken = "";

  SoftcorpAuthorize(
      {required ProjectServiceClient projectClient, required String apiKey}) {
    _grpcProjectClient = projectClient;
    _apiKey = apiKey;
  }

  @override
  Future<String> getAccessToken() async {
    // check if we have valid existing tokens
    if (_accessToken != "") {
      // validate tokens
      Map<String, dynamic>? decodedAccessToken = JwtDecoder.tryDecode(_accessToken)
      print(decodedAccessToken);
      bool hasExpired = JwtDecoder.isExpired(_accessToken);
      if (hasExpired == false) {
        return _accessToken;
      }
    }
    print(_apiKey);
    //if (!JwtDecoder.isExpired(_apiKey)) {
    //  throw Exception("api key is expired or otherwise malformed");
    //}
    try {
      ProjectRequest req = ProjectRequest();
      req.privateKey = _apiKey;
      ProjectResponse resp = await _grpcProjectClient.generateAccessToken(req);
      _accessToken = resp.accessToken;
      return _accessToken;
    } catch (e) {
      print("could not get access token");
      rethrow;
    }
  }
}

==> dart_blocks-0.0.16.tar.gz: lib/softcorp_authorize/softcorp_authorize.dart <==
import 'package:dart_softcorp_cloud/cloud_project.pbgrpc.dart';
import 'package:jwt_decoder/jwt_decoder.dart';

abstract class Authorize {
  Future<String> getAccessToken();
}

class SoftcorpAuthorize implements Authorize {
  // _grpcProjectClient is an object to communicate with the server
  late final ProjectServiceClient _grpcProjectClient;

  // _apiKey used to authorize requests
  String _apiKey = "";

  // _accessToken is used to connect clients to the api
  String _accessToken = "";

  SoftcorpAuthorize(
      {required ProjectServiceClient projectClient, required String apiKey}) {
    _grpcProjectClient = projectClient;
    _apiKey = apiKey;
  }

  @override
  Future<String> getAccessToken() async {
    // check if we have valid existing tokens
    if (_accessToken != "") {
      // validate tokens
      Map<String, dynamic>? decodedAccessToken = JwtDecoder.tryDecode(_accessToken);
      print(decodedAccessToken);
      bool hasExpired = JwtDecoder.isExpired(_accessToken);
      if (hasExpired == false) {
        return _accessToken;
      }
    }
    print(_apiKey);
    //if (!JwtDecoder.isExpired(_apiKey)) {
    //  throw Exception("api key is expired or otherwise malformed");
    //}
    try {
      ProjectRequest req = ProjectRequest();
      req.privateKey = _apiKey;
      ProjectResponse resp = await _grpcProjectClient.generateAccessToken(req);
      _accessToken = resp.accessToken;
      return _accessToken;
    } catch (e) {
      print("could not get access token");
      rethrow;
    }
  }
}
